@@ -1399,13 +1399,24 @@ always hide."
 
 ;;;_. Interface to Mew written by Hideyuki SHIRAI <shirai@meadowy.org>
 (eval-when-compile
-  (autoload 'mew-sinfo-get-disp-msg "mew")
-  (autoload 'mew-current-get-fld "mew")
-  (autoload 'mew-current-get-msg "mew")
-  (autoload 'mew-frame-id "mew")
-  (autoload 'mew-cache-hit "mew")
-  (autoload 'mew-xinfo-get-decode-err "mew")
-  (autoload 'mew-xinfo-get-action "mew"))
+  (condition-case nil
+      (progn
+	(require 'mew)
+	;; Avoid macro `mew-cache-hit' expand (Mew 1.94.2 or earlier).
+	;; Changed `mew-cache-hit' from macro to function at Mew 2.0.
+	(if (not (fboundp 'mew-current-get-fld))
+	    (setq byte-compile-macro-environment
+		  (cons '(mew-cache-hit . nil)
+			byte-compile-macro-environment))))
+    (error
+     ;; Silence byte compiler for environments where Mew does not installed.
+     (autoload 'mew-sinfo-get-disp-msg "mew")
+     (autoload 'mew-current-get-fld "mew")
+     (autoload 'mew-current-get-msg "mew")
+     (autoload 'mew-frame-id "mew")
+     (autoload 'mew-cache-hit "mew")
+     (autoload 'mew-xinfo-get-decode-err "mew")
+     (autoload 'mew-xinfo-get-action "mew"))))
 
 ;;;###autoload
 (defun lsdb-mew-insinuate ()
@@ -1631,7 +1642,7 @@ the user wants it."
 (provide 'lsdb)
 
 (product-provide 'lsdb
-  (product-define "LSDB" nil '(0 7)))
+  (product-define "LSDB" nil '(0 9)))
 
 ;;;_* Local emacs vars.
 ;;; The following `outline-layout' local variable setting:
